@@ -2,10 +2,10 @@ import argparse
 import os
 import sys
 
+from types import ModuleType
 from typing import Dict
 from typing import Tuple
 from typing import Union
-from types import ModuleType
 
 import numpy as np
 import pandas as pd
@@ -14,13 +14,13 @@ import tensorflow as tf
 
 from tensorflow.keras.models import load_model
 
+import PrognosAIs.Constants
 import PrognosAIs.IO.utils as IO_utils
 import PrognosAIs.Model.Losses
 import PrognosAIs.Model.Parsers as ModelParsers
 
 from PrognosAIs.IO import ConfigLoader
 from PrognosAIs.IO import DataGenerator
-import PrognosAIs.Constants
 
 
 class Evaluator:
@@ -761,10 +761,12 @@ class Evaluator:
                 out_file = os.path.join(
                     self.output_folder, i_dataset_name + "_predictions_combined_patches.csv"
                 )
+
+                _, sample_labels = self.get_sample_labels_from_patch_labels()
                 results_df = self.make_dataframe(
                     sample_names,
                     sample_predictions[i_dataset_name],
-                    self.get_real_labels_of_sample_subset(i_dataset_name),
+                    sample_labels[i_dataset_name],
                 )
                 results_df.to_csv(out_file, index=False)
 
